@@ -124,7 +124,7 @@ before 'setup_component' => sub {
     # Apply some column-specific defaults:
 
     # Set actual column headers (this is not required but real headers are displayed nicer):
-    my %col_props = ( $class->TableSpec_get_conf('column_properties') || () );
+    my %col_props = %{ $class->TableSpec_get_conf('column_properties') || {} };
     for my $col ($class->columns,$class->relationships) {
       $col_props{$col}{header} ||= $col;
     }
